@@ -69,11 +69,11 @@ def package_masks(iterable):
 
 def restriction_payload_splitter(iterable, post_process=lambda x: x):
     for line, lineno, path in iterable:
-        v = line.split()
+        pkg, *flags = line.split()
         try:
             # TODO: expand this invocation to allow threading token level validation down.
             # things like "is this a valid use flag?"
-            yield parse_match(v[0]), tuple(post_process(v[1:])), line, lineno, path
+            yield parse_match(pkg), tuple(post_process(flags)), line, lineno, path
         except ParseError as e:
             logger.warning(f"{path!r}, line {lineno}: parsing error: {e}")
 
@@ -90,27 +90,40 @@ def package_use_splitter(iterable):
     eapi_obj = get_latest_PMS_eapi()
 
     def f(tokens: list[str]):
-
+        start_idx = 0
         i = iter(tokens)
-        for idx, x in enumerate(i):
-            if x.endswith(":"):
+        for idx, flag in enumerate(i):
+            if flag == "-*":
+                start_idx = idx
+            elif flag.endswith(":"):
                 # we encountered `USE_EXPAND:` , thus all following tokens
                 # are values of that.
-                x = x.lower()[:-1]
-                l = tokens[0:idx]
+                use_expand = flag.lower()[:-1]
+                yield from tokens[start_idx:idx]
+                buffer: list[str] = []
                 for flag in i:
+                    if flag.endswith(":"):
+                        use_expand = flag.lower()[:-1]
+                        yield from buffer
+                        buffer.clear()
+                        continue
+                    if flag == "-*":
+                        buffer.clear()
+                        yield f"-{use_expand}_*"
+                        continue
                     if flag.startswith("-"):
-                        flag = f"-{x}_{flag[1:]}"
+                        flag = f"-{use_expand}_{flag[1:]}"
                     else:
-                        flag = f"{x}_{flag}"
+                        flag = f"{use_expand}_{flag}"
                     if not eapi_obj.is_valid_use_flag(flag.lstrip("-")):
                         raise ParseError(f"token {flag} is not a valid use flag")
-                    l.append(flag)
-                return l
-            elif not eapi_obj.is_valid_use_flag(x.lstrip("-")):
+                    buffer.append(flag)
+                yield from buffer
+                return
+            elif not eapi_obj.is_valid_use_flag(flag.lstrip("-")):
                 raise ParseError(f"token {flag} is not a valid use flag")
         # if we made it here, there's no USE_EXPAND; thus just return the original sequence
-        return tokens
+        yield from tokens[start_idx:]
 
     return restriction_payload_splitter(iterable, post_process=f)
 
@@ -227,7 +240,6 @@ def load_property(
 # instantiation manglers, and then the ebuild specific chunk (which is
 # selected by config)
 class domain(config_domain):
-
     # XXX ouch, verify this crap and add defaults and stuff
     _types = dict.fromkeys(
         (
@@ -251,7 +263,7 @@ class domain(config_domain):
 
     # TODO this is missing defaults
     pkgcore_config_type = ConfigHint(
-        _types,
+        types=_types,
         typename="domain",
         required=["repos", "profile", "vdb"],
         allow_unknowns=True,
@@ -303,7 +315,7 @@ class domain(config_domain):
 
         # if unset, MAKEOPTS defaults to CPU thread count
         if "MAKEOPTS" not in settings:
-            settings["MAKEOPTS"] = "-j%i" % cpu_count()
+            settings["MAKEOPTS"] = f"-j{cpu_count()}"
 
         # reformat env.d and make.conf incrementals
         system_profile_settings = {}
@@ -344,7 +356,7 @@ class domain(config_domain):
 
         if "ACCEPT_KEYWORDS" not in settings:
             raise Failure(
-                "No ACCEPT_KEYWORDS setting detected from profile, " "or user config"
+                "No ACCEPT_KEYWORDS setting detected from profile, or user config"
             )
         settings["ACCEPT_KEYWORDS"] = incremental_expansion(
             settings["ACCEPT_KEYWORDS"], msg_prefix="while expanding ACCEPT_KEYWORDS"
@@ -355,6 +367,11 @@ class domain(config_domain):
 
         return ImmutableDict(settings)
 
+    def get_settings_envvar(self, key: str, default=None):
+        if (val := self.settings.get(key)) is not None:
+            return val
+        return os.environ.get(key, default)
+
     @property
     def arch(self):
         try:
@@ -597,10 +614,8 @@ class domain(config_domain):
 
     @klass.jit_attr_none
     def use_expand_re(self):
-        return re.compile(
-            "^(?:[+-])?(%s)_(.*)$"
-            % "|".join(x.lower() for x in self.profile.use_expand)
-        )
+        expands = "|".join(x.lower() for x in self.profile.use_expand)
+        return re.compile(rf"^(?:[+-])?({expands})_(.*)$")
 
     def _split_use_expand_flags(self, use_stream):
         stream = ((self.use_expand_re.match(x), x) for x in use_stream)
@@ -764,7 +779,7 @@ class domain(config_domain):
         }
         data[f"conf:{path}"] = basics.AutoConfigSection(repo_conf_data)
         data[path] = basics.AutoConfigSection(repo_data)
-        config.update(data)
+        config.add_config_source(data)
 
         # reset repo-related jit attrs
         for attr in (x for x in dir(self) if x.startswith("_jit_repo_")):
