@@ -118,17 +118,23 @@ class ParseEclassDoc:
             return None
 
         # use literal blocks for all multiline text
-        data = ["::", "\n\n"]
+        data = ["\n\n"]
 
+        inside_code = False
         for i, line in enumerate(lines, 1):
             if self._code_tag.match(line):
-                continue
+                if not inside_code:
+                    data.append("::")
+                data.append("\n\n")
+                inside_code = not inside_code
             elif mo := self._subsection_tag.match(line):
                 header = _rst_header("~", mo.group("title"))
                 data.extend(f"{x}\n" for x in header)
-                data.extend(["::", "\n\n"])
+                data.extend(["\n\n"])
             elif line:
-                data.append(f"  {line}\n")
+                indent = "  " if inside_code else ""
+                formatted_line = line
+                data.append(f"{indent}{formatted_line}\n")
             else:
                 data.append("\n")
 
@@ -173,7 +179,7 @@ class ParseEclassDoc:
         """Return default field mapping for the block."""
         return {name: default for name, _required, _func, default in self.tags.values()}
 
-    def parse(self, lines, line_ind):
+    def parse(self, lines, line_ind, _next_line):
         """Parse an eclass block."""
         blocks = []
         data = self.defaults
@@ -218,7 +224,6 @@ class EclassBlock(ParseEclassDoc):
             "@PROVIDES:": ("raw_provides", False, self._tag_inline_list, ()),
             "@MAINTAINER:": ("maintainers", True, self._tag_multiline_args, None),
             "@AUTHOR:": ("authors", False, self._tag_multiline_args, None),
-            "@BUGREPORTS:": ("bugreports", False, self._tag_multiline_str, None),
             "@DESCRIPTION:": ("description", False, self._tag_multiline_str, None),
             "@EXAMPLE:": ("example", False, self._tag_multiline_str, None),
             "@SUPPORTED_EAPIS:": ("supported_eapis", False, self._supported_eapis, ()),
@@ -261,6 +266,15 @@ class EclassVarBlock(ParseEclassDoc):
         }
         super().__init__(tags)
 
+    def parse(self, lines, line_ind, next_line):
+        data = dict(super().parse(lines, line_ind, next_line))
+        var_name = data["name"]
+        if mo := re.search(rf"{var_name}=(?P<value>.*)", next_line):
+            data["initial_value"] = mo.group("value")
+        if mo := re.search(rf": \${{{var_name}:?=(?P<value>.*)}}", next_line):
+            data["default_value"] = mo.group("value")
+        return AttrDict(data)
+
 
 # For backwards compatibility, can be removed after 2022-12-31
 class EclassVarBlockCompat(ParseEclassDoc):
@@ -493,13 +507,13 @@ class EclassDoc(AttrDict):
                     block = []
                     block_start = line_ind + 1
                     while line_ind < len(lines):
-                        line = lines[line_ind]
+                        next_line = line = lines[line_ind]
                         if not line.startswith(prefix):
                             break
                         line = line[len(prefix) + 1 :]
                         block.append(line)
                         line_ind += 1
-                    blocks.append((tag, block, block_start))
+                    blocks.append((tag, block, block_start, next_line))
                 line_ind += 1
 
         # set default fields
@@ -527,9 +541,9 @@ class EclassDoc(AttrDict):
         duplicates = {k: set() for k in ParseEclassDoc.blocks}
 
         # parse identified blocks
-        for tag, block, block_start in blocks:
+        for tag, block, block_start, next_line in blocks:
             block_obj = ParseEclassDoc.blocks[tag]
-            block_data = block_obj.parse(block, block_start)
+            block_data = block_obj.parse(block, block_start, next_line)
             # check if duplicate blocks exist and merge data
             if block_obj.key is None:
                 # main @ECLASS block
@@ -564,7 +578,9 @@ class EclassDoc(AttrDict):
 
         rst = _header_only("=", self.name, leading=True)
         if self.blurb:
-            rst.extend(_header_only("-", self.blurb, leading=True))
+            rst.extend(_rst_header("-", "Name"))
+            rst.append(f"``{self.name}`` -- {self.blurb}")
+            rst.append("")
 
         if self.description:
             rst.extend(_rst_header("-", "Description"))
@@ -584,31 +600,49 @@ class EclassDoc(AttrDict):
             rst.append("")
         if self.raw_provides:
             rst.extend(_rst_header("-", "Transitively Provided Eclasses"))
-            rst.append(" ".join(self.raw_provides))
+            rst.extend(f"- ``{provide}``" for provide in self.raw_provides)
             rst.append("")
         if self.example:
             rst.extend(_rst_header("-", "Example"))
             rst.append(self.example)
             rst.append("")
 
+        raw_eclass_name = self.name[: -len(".eclass")]
+        latest_eapi = EAPI.known_eapis[sorted(EAPI.known_eapis)[-1]]
+        if exported_phases := [
+            x
+            for x in latest_eapi.phases.values()
+            if f"{raw_eclass_name}_{x}" in self.exported_function_names
+        ]:
+            rst.extend(_rst_header("-", "Exported Phases"))
+            rst.extend(f"- ``{phase}``" for phase in exported_phases)
+            rst.append("")
+
         if external_funcs := [x for x in self.functions if not x.internal]:
             rst.extend(_header_only("-", "Functions"))
             for func in external_funcs:
                 header = [func.name]
                 if func.usage:
                     header.append(func.usage)
-                rst.extend(_rst_header("~", " ".join(header)))
+                rst.append(f'**{" ".join(header)}**')
                 if func.description:
-                    rst.append(func.description)
+                    rst.append(
+                        "  " + func.description.lstrip("\n").replace("\n", "\n  ")
+                    )
                 if func.returns:
                     if func.description:
-                        rst.append("")
-                    rst.append(f"Return value: {func.returns}")
+                        rst.append("  ")
+                    rst.append(f"  **Return value**: {func.returns}")
                 rst.append("")
         if external_vars := [x for x in self.variables if not x.internal]:
             rst.extend(_header_only("-", "Variables"))
             for var in external_vars:
                 vartype = ""
+                var_value = ""
+                if default_value := getattr(var, "default_value", None):
+                    var_value = f" ?= *{default_value}*"
+                elif initial_value := getattr(var, "initial_value", None):
+                    var_value = f" = *{initial_value}*"
                 if var.required:
                     vartype += " (REQUIRED)"
                 if var.pre_inherit:
@@ -616,11 +650,12 @@ class EclassDoc(AttrDict):
                 if var.user_variable:
                     vartype += " (USER VARIABLE)"
                 if var.output_variable:
-                    vartype += " (OUTPUT VARIABLE)"
-
-                rst.extend(_rst_header("~", var.name + vartype))
+                    vartype += " (GENERATED BY ECLASS)"
+                rst.append(f"**{var.name}**{var_value}{vartype}")
                 if var.description:
-                    rst.append(var.description)
+                    rst.append(
+                        "  " + var.description.lstrip("\n").replace("\n", "\n  ")
+                    )
                 rst.append("")
         if external_func_vars := [x for x in self.function_variables if not x.internal]:
             rst.extend(_header_only("-", "Function Variables"))
@@ -629,9 +664,11 @@ class EclassDoc(AttrDict):
                 if var.required:
                     vartype += " (REQUIRED)"
 
-                rst.extend(_rst_header("~", var.name + vartype))
+                rst.append(f"**{var.name}**{vartype}")
                 if var.description:
-                    rst.append(var.description)
+                    rst.append(
+                        "  " + var.description.lstrip("\n").replace("\n", "\n  ")
+                    )
                 rst.append("")
 
         if self.authors:
@@ -642,10 +679,10 @@ class EclassDoc(AttrDict):
             rst.extend(_rst_header("-", "Maintainers"))
             rst.append("\n".join(f"| {x}" for x in self.maintainers))
             rst.append("")
-        if self.bugreports:
-            rst.extend(_rst_header("-", "Bug Reports"))
-            rst.append(self.bugreports)
-            rst.append("")
+
+        rst.extend(_rst_header("-", "Reporting Bugs"))
+        rst.append("Please report bugs via https://bugs.gentoo.org/")
+        rst.append("")
 
         return "\n".join(rst)
 
@@ -688,6 +725,7 @@ class EclassDoc(AttrDict):
                 super().__init__(*args, **kwargs)
                 self._docinfo.update(man_data)
 
+        self.blurb = None  # skip addition of blurb as man page header already holds it
         writer = manpage.Writer()
         writer.translator_class = Translator
         return self._to_docutils(writer)
@@ -697,3 +735,9 @@ class EclassDoc(AttrDict):
         from docutils.writers import html5_polyglot
 
         return self._to_docutils(html5_polyglot.Writer())
+
+    def to_devbook(self):
+        """Convert eclassdoc object to an HTML 5 document."""
+        from pkgcore.util.rst2devbook import DevBookWriter
+
+        return self._to_docutils(DevBookWriter(self.name))
