@@ -231,7 +231,6 @@ class MetadataXml:
 
 
 class LocalMetadataXml(MetadataXml):
-
     __slots__ = ()
 
     def _parse_xml(self):
@@ -248,7 +247,6 @@ class LocalMetadataXml(MetadataXml):
 
 
 class SharedPkgData:
-
     __slots__ = ("__weakref__", "metadata_xml", "manifest")
 
     def __init__(self, metadata_xml, manifest):
@@ -465,7 +463,6 @@ class ProjectsXml:
 
 
 class LocalProjectsXml(ProjectsXml):
-
     __slots__ = ()
 
     def _parse_xml(self):
@@ -477,7 +474,6 @@ class LocalProjectsXml(ProjectsXml):
 
 
 class Licenses(metaclass=WeakInstMeta):
-
     __inst_caching__ = True
     __slots__ = (
         "_base",
@@ -530,11 +526,13 @@ class Licenses(metaclass=WeakInstMeta):
             d = read_dict(self.license_groups_path, splitter=" ")
             for k, v in d.items():
                 d[k] = set(v.split())
-        except EnvironmentError:
-            return mappings.ImmutableDict()
+        except EnvironmentError as e:
+            if e.errno != errno.ENOENT:
+                logger.error(f"failed reading parsing license_groups: {e}")
+            d = {}
         except BashParseError as pe:
             logger.error(f"failed parsing license_groups: {pe}")
-            return mappings.ImmutableDict()
+            d = {}
         for li in self._license_instances:
             for k, v in li.groups.items():
                 if k in d:
@@ -600,7 +598,6 @@ class Licenses(metaclass=WeakInstMeta):
 
 
 class _immutable_attr_dict(mappings.ImmutableDict):
-
     __slots__ = ()
 
     mappings.inject_getitem_as_getattr(locals())
@@ -612,7 +609,6 @@ _KnownProfile = namedtuple(
 
 
 class Profiles(klass.ImmutableInstance):
-
     __slots__ = ("config", "profiles_base", "_profiles")
     __inst_caching__ = True
 
@@ -710,7 +706,6 @@ class Profiles(klass.ImmutableInstance):
 
 
 class OverlayedProfiles(Profiles):
-
     __inst_caching__ = True
     __slots__ = ("_profiles_instances", "_profiles_sources")
 
@@ -771,7 +766,7 @@ class RepoConfig(syncable.tree, klass.ImmutableInstance, metaclass=WeakInstMeta)
         object.__setattr__(self, "config_name", config_name)
         object.__setattr__(self, "external", (config_name is None))
         object.__setattr__(self, "location", location)
-        object.__setattr__(self, "profiles_base", pjoin(self.location, profiles_base))
+        object.__setattr__(self, "profiles_base", pjoin(location, profiles_base))
 
         try:
             self._parse_config()
@@ -959,6 +954,7 @@ class RepoConfig(syncable.tree, klass.ImmutableInstance, metaclass=WeakInstMeta)
     @klass.jit_attr
     def use_desc(self):
         """Global USE flags for the repo."""
+
         # todo: convert this to using a common exception base, with
         # conversion of ValueErrors...
         def converter(key):
