@@ -11,7 +11,7 @@ def passthrough(*args, **kwargs):
 def test_invalid_config_types():
     for var in ("class", "inherit"):
 
-        @configurable({var: "str"})
+        @configurable(types={var: "str"})
         def testtype():
             pass
 
@@ -196,6 +196,7 @@ class TestConfigHint:
     def test_clone(self):
         c = ConfigHint(
             types={"foo": "list", "one": "str"},
+            # use lists to ensure it forces immutability.
             positional=["one"],
             required=["one"],
             typename="barn",
@@ -205,8 +206,8 @@ class TestConfigHint:
             types={"foo": "list", "one": "str", "two": "str"}, required=["one", "two"]
         )
         assert c2.types == {"foo": "list", "one": "str", "two": "str"}
-        assert c2.positional == c.positional
-        assert c2.required == ["one", "two"]
+        assert c2.positional == tuple(c.positional)
+        assert c2.required == ("one", "two")
         assert c2.typename == c.typename
         assert c2.allow_unknowns == c.allow_unknowns
         assert c2.doc == c.doc
@@ -247,87 +248,6 @@ class TestDictConfigSection:
             section.render_value(None, "list", "spoon")
 
 
-class TestFakeIncrementalDictConfigSection:
-    @staticmethod
-    def _convert(central, value, arg_type):
-        return central, value, arg_type
-
-    @staticmethod
-    def _fail(central, value, arg_type):
-        raise errors.ConfigurationError("fail")
-
-    def test_misc(self):
-        section = basics.FakeIncrementalDictConfigSection(
-            self._convert, {"list": [1, 2]}
-        )
-        assert "foo" not in section
-        assert "list" in section
-        assert ["list"] == list(section.keys())
-        with pytest.raises(errors.ConfigurationError):
-            obj = basics.FakeIncrementalDictConfigSection(self._fail, {"a": "b"})
-            obj.render_value(None, "a", "str")
-
-    def test_fake_incrementals(self):
-        section = basics.FakeIncrementalDictConfigSection(
-            self._convert, {"seq.append": [1, 2]}
-        )
-        manager = object()
-        assert [None, None, (manager, [1, 2], "list")] == section.render_value(
-            manager, "seq", "list"
-        )
-
-        def _repr(central, value, arg_type):
-            return "list", ["thing"]
-
-        section = basics.FakeIncrementalDictConfigSection(_repr, {"foo": None})
-        assert ("list", (None, ["thing"], None)) == section.render_value(
-            manager, "foo", "repr"
-        )
-        with pytest.raises(errors.ConfigurationError):
-            obj = basics.FakeIncrementalDictConfigSection(
-                self._fail, {"a.prepend": "b"}
-            )
-            obj.render_value(None, "a", "list")
-
-    def test_repr(self):
-        def asis(central, value, arg_type):
-            assert arg_type == "repr", arg_type
-            return value
-
-        source_dict = {
-            "seq.append": ("list", [1, 2]),
-            "simple": ("bool", True),
-            "multistr": ("str", "body"),
-            "multistr.prepend": ("str", "head"),
-            "refs": ("str", "lost"),
-            "refs.append": ("ref", "main"),
-            "refs.prepend": ("refs", ["a", "b"]),
-            "strlist": ("callable", asis),
-            "strlist.prepend": ("str", "whatever"),
-            "wrong.prepend": ("wrong", "wrong"),
-        }
-        section = basics.FakeIncrementalDictConfigSection(asis, source_dict)
-        manager = object()
-        with pytest.raises(KeyError):
-            section.render_value(manager, "spoon", "repr")
-        assert ("list", [None, None, [1, 2]]) == section.render_value(
-            manager, "seq", "repr"
-        )
-        assert ("bool", True) == section.render_value(manager, "simple", "repr")
-        assert ("str", ["head", "body", None]) == section.render_value(
-            manager, "multistr", "repr"
-        )
-        assert ("refs", [["a", "b"], ["lost"], ["main"]]) == section.render_value(
-            manager, "refs", "repr"
-        )
-        assert (
-            "list",
-            [["whatever"], ["tests.config.test_basics.asis"], None],
-        ) == section.render_value(manager, "strlist", "repr")
-        with pytest.raises(errors.ConfigurationError):
-            section.render_value(manager, "wrong", "repr")
-
-
 class TestConvertString:
     def test_render_value(self):
         source = {
@@ -408,7 +328,6 @@ class TestConvertString:
 
 
 class TestConvertAsIs:
-
     source = {
         "str": "tests",
         "bool": True,
