@@ -1,8 +1,8 @@
 import pytest
+from snakeoil.errors import walk_exception_chain
 
 from pkgcore.config import basics, central, errors
 from pkgcore.config.hint import configurable
-from snakeoil.errors import walk_exception_chain
 
 
 # A bunch of functions used from various tests below.
@@ -10,7 +10,7 @@ def repo(cache):
     return cache
 
 
-@configurable({"content": "ref:drawer", "contents": "refs:drawer"})
+@configurable(types={"content": "ref:drawer", "contents": "refs:drawer"})
 def drawer(content=None, contents=None):
     return content, contents
 
@@ -27,7 +27,6 @@ def drawer(content=None, contents=None):
 
 
 class RemoteSource:
-
     """Use this one for tests that do need the names but nothing more."""
 
     def __iter__(self):
@@ -391,7 +390,7 @@ def test_reinstantiate_after_raise():
     # reprocess already processed section_ref args.
     spork = object()
 
-    @configurable({"thing": "ref:spork"})
+    @configurable(types={"thing": "ref:spork"})
     def myrepo(thing):
         assert thing is spork
         raise errors.ComplexInstantiationError("I suck")
@@ -585,11 +584,11 @@ def test_alias():
 
 
 def test_typecheck():
-    @configurable({"myrepo": "ref:repo"}, typename="repo")
+    @configurable(types={"myrepo": "ref:repo"}, typename="repo")
     def reporef(myrepo=None):
         return myrepo
 
-    @configurable({"myrepo": "refs:repo"}, typename="repo")
+    @configurable(types={"myrepo": "refs:repo"}, typename="repo")
     def reporefs(myrepo=None):
         return myrepo
 
@@ -804,11 +803,15 @@ def test_autoload_wrong_type():
 
 
 def test_lazy_refs():
-    @configurable({"myrepo": "lazy_ref:repo", "thing": "lazy_ref"}, typename="repo")
+    @configurable(
+        types={"myrepo": "lazy_ref:repo", "thing": "lazy_ref"}, typename="repo"
+    )
     def reporef(myrepo=None, thing=None):
         return myrepo, thing
 
-    @configurable({"myrepo": "lazy_refs:repo", "thing": "lazy_refs"}, typename="repo")
+    @configurable(
+        types={"myrepo": "lazy_refs:repo", "thing": "lazy_refs"}, typename="repo"
+    )
     def reporefs(myrepo=None, thing=None):
         return myrepo, thing
 
@@ -966,89 +969,3 @@ def test_self_inherit():
     )
     assert manager.collapse_named_section("self")
     assert manager.collapse_section([section])
-
-
-def test_prepend_inherit():
-    manager = central.ConfigManager(
-        [{"sect": basics.HardCodedConfigSection({"inherit.prepend": ["self"]})}]
-    )
-    check_error(
-        "Collapsing section named 'sect':\n"
-        "Prepending or appending to the inherit list makes no sense",
-        manager.collapse_named_section,
-        "sect",
-    )
-
-
-def test_list_prepend():
-    @configurable({"seq": "list"})
-    def seq(seq):
-        return seq
-
-    manager = central.ConfigManager(
-        [
-            {
-                "inh": basics.HardCodedConfigSection(
-                    {
-                        "inherit": ["sect"],
-                        "seq.prepend": ["pre"],
-                    }
-                ),
-                "sect": basics.HardCodedConfigSection(
-                    {
-                        "inherit": ["base"],
-                        "seq": ["1", "2"],
-                    }
-                ),
-            },
-            {
-                "base": basics.HardCodedConfigSection(
-                    {
-                        "class": seq,
-                        "seq.prepend": ["-1"],
-                        "seq.append": ["post"],
-                    }
-                )
-            },
-        ]
-    )
-    assert ["-1", "post"] == manager.objects.seq["base"]
-    assert ["1", "2"] == manager.objects.seq["sect"]
-    assert ["pre", "1", "2"] == manager.objects.seq["inh"]
-
-
-def test_str_prepend():
-    @configurable({"string": "str"})
-    def sect(string):
-        return string
-
-    manager = central.ConfigManager(
-        [
-            {
-                "inh": basics.HardCodedConfigSection(
-                    {
-                        "inherit": ["sect"],
-                        "string.prepend": "pre",
-                    }
-                ),
-                "sect": basics.HardCodedConfigSection(
-                    {
-                        "inherit": ["base"],
-                        "string": "b",
-                    }
-                ),
-            },
-            {
-                "base": basics.HardCodedConfigSection(
-                    {
-                        "class": sect,
-                        "string.prepend": "a",
-                        "string.append": "c",
-                    }
-                )
-            },
-        ]
-    )
-    assert "a c" == manager.objects.sect["base"]
-    assert "b" == manager.objects.sect["sect"]
-    assert "pre b" == manager.objects.sect["inh"]
