@@ -2,6 +2,7 @@ import textwrap
 from io import StringIO
 
 import pytest
+
 from pkgcore.config import central, cparser, errors
 
 
@@ -33,8 +34,6 @@ class TestConfigFromIni:
             [test]
             string = 'hi I am a string'
             list = foo bar baz
-            list.prepend = pre bits
-            list.append = post bits
             true = yes
             false = no
         """
@@ -44,11 +43,11 @@ class TestConfigFromIni:
         assert list(config.keys()) == ["test"]
         section = config["test"]
         for key, arg_type, value in (
-            ("string", "str", [None, "hi I am a string", None]),
+            ("string", "str", "hi I am a string"),
             (
                 "list",
                 "list",
-                [["pre", "bits"], ["foo", "bar", "baz"], ["post", "bits"]],
+                ["foo", "bar", "baz"],
             ),
             ("true", "bool", True),
             ("false", "bool", False),
