@@ -19,7 +19,6 @@ def generate_misc_sufs():
 
 
 class TestCPV:
-
     good_cats = (
         "dev-util",
         "dev+",
@@ -53,6 +52,7 @@ class TestCPV:
         "+dfa",
         "timidity--9f",
         "ormaybe---13_beta",
+        "bar-11-r3",
     )
 
     good_cp = (
@@ -64,6 +64,7 @@ class TestCPV:
         "bah/f-100dpi",
         "dev-util/diffball-blah-monkeys",
         "virtual/7z",
+        "x11-drivers/xf86-video-r128",
     )
 
     good_vers = ("1", "2.3.4", "2.3.4a", "02.3", "2.03", "3d", "3D")
