@@ -179,7 +179,7 @@ class TestUnconfiguredTree:
         (tmp_path / "empty" / "empty").mkdir(parents=True)
         (tmp_path / "cat" / "pkg" / "pkg-3.ebuild").touch()
         repo = self.mk_tree(tmp_path)
-        assert {"cat": (), "empty": ()} == dict(repo.categories)
+        assert frozenset(["cat", "empty"]) == frozenset(repo.categories)
         assert {"cat": ("pkg",), "empty": ("empty",)} == dict(repo.packages)
         assert {("cat", "pkg"): ("3",), ("empty", "empty"): ()} == dict(repo.versions)
 
@@ -199,6 +199,32 @@ class TestUnconfiguredTree:
             atom("<just/newer-than-42"),
         }
 
+    def test_stabilization_groups(self, tmp_path, caplog):
+        base = tmp_path / "metadata/stabilization-groups"
+        (base / "pkgcore").mkdir(parents=True)
+        (base / "gentoo.group").write_text(
+            """\
+                # some text here
+                    dev-python/pkgcore
+                dev-python/pytest # comment
+                @bad_atom@
+            """
+        )
+        (base / "pkgcore" / "snakeoil.group").write_text(
+            """dev-python/snakeoil # comment"""
+        )
+        (base / "pkgcore" / "pkgdev").write_text("""dev-python/pkgdev # comment""")
+        mirrors = self.mk_tree(tmp_path).stabilization_groups
+        assert set(mirrors.keys()) == {"gentoo", "pkgcore/snakeoil"}
+        assert set(mirrors["gentoo"]) == {
+            atom("dev-python/pkgcore"),
+            atom("dev-python/pytest"),
+        }
+        assert set(mirrors["pkgcore/snakeoil"]) == {
+            atom("dev-python/snakeoil"),
+        }
+        assert "line 4: parsing error:" in caplog.text
+
 
 class TestSlavedTree(TestUnconfiguredTree):
     def mk_tree(self, path, *args, **kwds):
@@ -270,7 +296,7 @@ class TestSlavedTree(TestUnconfiguredTree):
         repo = self.mk_tree(slave_repo)
         assert set(repo.licenses) == set(master_licenses + slave_licenses)
 
-    def test_license_groups(self, master_repo, slave_repo):
+    def test_license_groups(self, master_repo, slave_repo, caplog):
         master_licenses = ("GPL-2", "BSD")
         slave_licenses = ("BSD-2", "MIT")
 
@@ -298,6 +324,26 @@ class TestSlavedTree(TestUnconfiguredTree):
         }
         assert "BSD" in repo.licenses.groups["MISC-FREE"]
 
+        # verify it warns when parsing fails
+        (slave_repo / "profiles" / "license_groups").write_text('X"')
+        caplog.clear()
+        repo = self.mk_tree(slave_repo)
+        assert set(repo.licenses.groups) == {"FREE", "OSI-APPROVED"}
+        assert caplog.text
+
+        # verify it warns when the file exists but it can't read it.
+        (slave_repo / "profiles" / "license_groups").write_text("")
+        (slave_repo / "profiles" / "license_groups").chmod(000)
+        caplog.clear()
+        repo = self.mk_tree(slave_repo)
+        assert set(repo.licenses.groups) == {"FREE", "OSI-APPROVED"}
+        assert caplog.text
+
+        # verify it handles a missing license group.
+        (slave_repo / "profiles" / "license_groups").unlink()
+        repo = self.mk_tree(slave_repo)
+        assert set(repo.licenses.groups) == {"FREE", "OSI-APPROVED"}
+
     def test_package_deprecated(self, slave_repo, master_repo):
         (master_repo / "profiles" / "package.deprecated").write_text(
             textwrap.dedent(
