@@ -1,11 +1,12 @@
 import pytest
+
 from pkgcore.config import basics, errors
 from pkgcore.config.hint import configurable
 from pkgcore.scripts import pconfig
 from pkgcore.test.scripts.helpers import ArgParseMixin
 
 
-@configurable({"reff": "ref:spork"})
+@configurable(types={"reff": "ref:spork"})
 def spork(reff):
     """Test thing."""
 
@@ -49,7 +50,6 @@ def increment(inc=()):
 
 
 class DescribeClassTest(ArgParseMixin):
-
     _argparser = pconfig.describe_class
 
     def test_parser(self, capsys):
@@ -94,7 +94,6 @@ class DescribeClassTest(ArgParseMixin):
 
 
 class TestClasses(ArgParseMixin):
-
     _argparser = pconfig.classes
 
     def test_classes(self):
@@ -146,7 +145,6 @@ class TestClasses(ArgParseMixin):
 
 
 class TestDump(ArgParseMixin):
-
     _argparser = pconfig.dump
 
     def test_dump(self):
@@ -260,7 +258,6 @@ class TestDump(ArgParseMixin):
 
 
 class TestUncollapsable(ArgParseMixin):
-
     _argparser = pconfig.uncollapsable
 
     def test_uncollapsable(self):
@@ -281,7 +278,6 @@ class TestUncollapsable(ArgParseMixin):
 
 
 class TestConfigurables(ArgParseMixin):
-
     _argparser = pconfig.configurables
 
     def test_configurables(self):
@@ -300,15 +296,13 @@ class WeirdSection(basics.ConfigSection):
             raise KeyError(name)
         if arg_type != "repr":
             raise errors.ConfigurationError(f"{arg_type!r} unsupported")
-        return "refs", [
+        return (
+            "refs",
             ["spork", basics.HardCodedConfigSection({"foo": "bar"})],
-            None,
-            None,
-        ]
+        )
 
 
 class TestDumpUncollapsed(ArgParseMixin):
-
     _argparser = pconfig.dump_uncollapsed
 
     def test_dump_uncollapsed(self):
@@ -342,7 +336,7 @@ class TestDumpUncollapsed(ArgParseMixin):
                 "    nested section 2",
                 "    ================",
                 "    # type: refs",
-                "    'sects.prepend' = ",
+                "    'sects' = ",
                 "        nested section 1",
                 "        ================",
                 "        named section 'spork'",
