@@ -1,6 +1,9 @@
 from functools import partial
 from io import BytesIO
 
+from snakeoil.formatters import PlainTextFormatter
+from snakeoil.mappings import AttrAccessible
+
 from pkgcore.config import basics
 from pkgcore.config.hint import ConfigHint
 from pkgcore.ebuild.cpv import CPV
@@ -8,9 +11,8 @@ from pkgcore.operations.repo import install, operations, replace, uninstall
 from pkgcore.repository import syncable, util
 from pkgcore.scripts import pmaint
 from pkgcore.sync import base
+from pkgcore.test.misc import FakePkg
 from pkgcore.test.scripts.helpers import ArgParseMixin
-from snakeoil.formatters import PlainTextFormatter
-from snakeoil.mappings import AttrAccessible
 
 Options = AttrAccessible
 
@@ -32,14 +34,15 @@ class fake_operations(operations):
 
 
 class FakeRepo(util.SimpleTree):
-
     operations_kls = fake_operations
 
     def __init__(self, data, frozen=False, livefs=False, repo_id=None):
         self.installed = []
         self.replaced = []
         self.uninstalled = []
-        super().__init__(data, pkg_klass=partial(fake_pkg, self), repo_id=repo_id)
+        super().__init__(
+            data, pkg_klass=partial(FakePkg.for_tree_usage, repo=self), repo_id=repo_id
+        )
         self.livefs = livefs
         self.frozen = frozen
 
@@ -53,9 +56,8 @@ def make_repo_config(repo_data, livefs=False, frozen=False, repo_id=None):
 
 
 class FakeDomain:
-
     pkgcore_config_type = ConfigHint(
-        {"repos": "refs:repo", "binpkg": "refs:repo", "vdb": "refs:repo"},
+        types={"repos": "refs:repo", "binpkg": "refs:repo", "vdb": "refs:repo"},
         typename="domain",
     )
 
@@ -96,13 +98,12 @@ class FakeSyncer(base.Syncer):
         super().__init__(*args, **kwargs)
         self.synced = False
 
-    def _sync(self, verbosity, output_fd, **kwds):
+    def _sync(self, verbosity, **kwds):
         self.synced = True
         return self.succeed
 
 
 class SyncableRepo(syncable.tree, util.SimpleTree):
-
     pkgcore_config_type = ConfigHint(typename="repo_config")
 
     def __init__(self, succeed=True):
@@ -120,7 +121,6 @@ failure_section = basics.HardCodedConfigSection(
 
 
 class TestSync(ArgParseMixin):
-
     _argparser = pmaint.sync
 
     def test_parser(self):
@@ -137,7 +137,7 @@ class TestSync(ArgParseMixin):
             ],
             myrepo=success_section,
         )
-        assert config.repo_config["myrepo"]._syncer.synced
+        assert config.objects.repo_config["myrepo"]._syncer.synced
         self.assertOut(
             [
                 "*** syncing myrepo",
@@ -164,12 +164,6 @@ class TestSync(ArgParseMixin):
         )
 
 
-class fake_pkg(CPV):
-    def __init__(self, repo, *a, **kw):
-        CPV.__init__(self, *a, **kw)
-        object.__setattr__(self, "repo", repo)
-
-
 def derive_op(name, op, *a, **kw):
     if isinstance(name, str):
         name = [name]
@@ -187,7 +181,6 @@ def derive_op(name, op, *a, **kw):
 
 
 class TestCopy(ArgParseMixin):
-
     _argparser = pmaint.copy
 
     def execute_main(self, *a, **kw):
@@ -205,7 +198,7 @@ class TestCopy(ArgParseMixin):
             domain=make_domain(vdb={"sys-apps": {"portage": ["2.1", "2.3"]}}),
         )
         assert ret == 0, "expected non zero exit code"
-        assert list(map(str, config.target_repo.installed)) == [
+        assert [pkg.cpvstr for pkg in config.target_repo.installed] == [
             "sys-apps/portage-2.1",
             "sys-apps/portage-2.3",
         ]
@@ -222,7 +215,7 @@ class TestCopy(ArgParseMixin):
             domain=make_domain(binpkg=d, vdb=d),
         )
         assert ret == 0, "expected non zero exit code"
-        assert [list(map(str, x)) for x in config.target_repo.replaced] == [
+        assert [[x.cpvstr for x in pkg] for pkg in config.target_repo.replaced] == [
             ["sys-apps/portage-2.1", "sys-apps/portage-2.1"]
         ]
         assert (
@@ -239,7 +232,7 @@ class TestCopy(ArgParseMixin):
             domain=make_domain(vdb={"sys-apps": {"portage": ["2.1", "2.3"]}}),
         )
         assert ret == 0, "expected non zero exit code"
-        assert list(map(str, config.target_repo.installed)) == [
+        assert [pkg.cpvstr for pkg in config.target_repo.installed] == [
             "sys-apps/portage-2.1",
             "sys-apps/portage-2.3",
         ]
@@ -259,18 +252,18 @@ class TestCopy(ArgParseMixin):
             ),
         )
         assert ret == 0, "expected non zero exit code"
-        assert list(map(str, config.target_repo.installed)) == ["sys-apps/portage-2.3"]
+        assert [pkg.cpvstr for pkg in config.target_repo.installed] == [
+            "sys-apps/portage-2.3"
+        ]
         assert (
             config.target_repo.uninstalled == config.target_repo.replaced
         ), "uninstalled should be the same as replaced; empty"
 
 
 class TestRegen(ArgParseMixin):
-
     _argparser = pmaint.regen
 
     def test_parser(self):
-
         options = self.parse("fake", "--threads", "2", domain=make_domain())
         assert isinstance(options.repos[0], util.SimpleTree)
         assert options.threads == 2
